const isMarkActive = (state, type) => {
    const { from, $from, to, empty } = state.selection;
    if (empty) {
        return !!type.isInSet(state.storedMarks || $from.marks());
    }
    else {
        return state.doc.rangeHasMark(from, to, type);
    }
};

const getSelectionMarks = (state) => {
    let marks = [];
    const { selection: { from, to } } = state;
    state.doc.nodesBetween(from, to, node => {
        marks = [...marks, ...node.marks];
    });
    return marks;
};

const isLinkActive = (state) => {
    const { schema, selection: { anchor, head, from, to } } = state;
    if (!schema.marks.link) {
        return false;
    }
    const isForwardSelection = anchor === from;
    const linkMarks = getSelectionMarks(state).filter(mark => mark.type === schema.marks.link);
    const selectionHasOnlyMarks = isForwardSelection ?
        (state.doc.rangeHasMark(anchor, anchor + 1, schema.marks.link) &&
            state.doc.rangeHasMark(head - 1, head, schema.marks.link)) : (state.doc.rangeHasMark(anchor - 1, anchor, schema.marks.link) &&
        state.doc.rangeHasMark(head, head + 1, schema.marks.link));
    if (linkMarks.length === 1 && selectionHasOnlyMarks) {
        return true;
    }
    return false;
};

const removeLink = (view) => {
    const { state: { doc, selection, tr }, dispatch } = view;
    const { $head: { pos }, from, to } = selection;
    // if the cursor is on the link without any selection
    if (from === to) {
        const $pos = doc.resolve(pos);
        const linkStart = pos - $pos.textOffset;
        const linkEnd = linkStart + $pos.parent.child($pos.index()).nodeSize;
        tr.removeMark(linkStart, linkEnd);
    }
    else {
        tr.removeMark(from, to);
    }
    dispatch(tr);
};

const findNodeType = (type, $from) => {
    for (let i = $from.depth; i > 0; i--) {
        if ($from.node(i).type === type) {
            return $from.node(i).type;
        }
    }
    return null;
};
const ɵ0 = findNodeType;
const isNodeActive = (state, type, attrs = {}) => {
    const { $from, to } = state.selection;
    const node = findNodeType(type, $from);
    if (!Object.entries(attrs).length || !node) {
        return !!node;
    }
    return to <= $from.end() && $from.parent.hasMarkup(type, attrs);
};

const isListItem = (type, schema) => {
    return (type === schema.nodes.list_item ||
        type === schema.nodes.ordered_list ||
        type === schema.nodes.bullet_list);
};

const calculateBubblePos = (view, toolTipEl) => {
    const { state: { selection } } = view;
    const { from, to } = selection;
    // These are in screen coordinates
    const start = view.coordsAtPos(from);
    const end = view.coordsAtPos(to);
    // The box in which the tooltip is positioned, to use as base
    const parent = toolTipEl.offsetParent;
    const box = parent.getBoundingClientRect();
    // Find a center-ish x position from the selection endpoints (when
    // crossing lines, end may be more to the left)
    const left = Math.max((start.left + end.left) / 2, start.left + 3);
    return {
        left: left - box.left,
        bottom: box.bottom - start.top
    };
};

/**
 * Generated bundle index. Do not edit.
 */

export { calculateBubblePos, getSelectionMarks, isLinkActive, isListItem, isMarkActive, isNodeActive, removeLink, ɵ0 };
//# sourceMappingURL=ngx-editor-helpers.js.map
